#install.sh
#===============================================================================================
# Spreader Report Configuration for CS550
# This assumes that you already have a GPSReport configure for reporting GPSData.
#
# NOTE: Ensure that there is space available in the requested GPSReport to add in the PCYP message
#	( ie less than 4 have already been added ) when using gpsaddmes
#
# 	SPREADER_GPS_REPORT 		=> The already configured GPSCondition report to use.
#	SPREADER_GPS_REPORT_SCRIPT 	=> The matching report script to call
#
# Also sets up the PCYP String
# ****** CONFIGURE SETTINGS HERE ****************
#===============================================================================================
SPREADER_GPS_REPORT=1                           # GPS Report to trigger spreader app to run
SPREADER_GPS_REPORT_SCRIPT=1020                 # The report script number to use
SPREADER_PCYP_STRING=1000			            # Set the PCYP id to use.
SPREADER_RESET_PCYP_STRING=1500                 # The PCYP string id for reset command

SPREADER_TMP_TO_NV_REPORT=51                    # Report to copy from /tmp to SD card
SPREADER_NV_TO_TMP_REPORT=52                    # Report to copy from SD to /tmp
SPREADER_RESET_REPORT=99                        # Reset report number
SPREADER_RESET_DEST=cypressvue.com              # Reset report destination

SPREADER_BAUD_RATE=115200                       #
VCC_REPORT_TRIGGER=3                            # VCC trigger while ignition on
DATA_SAVE_TIME=1800                             # How often spreader data saved to SD while ign on

IGN_OFF_TIGGER=7                                # Report trigger for ignition off
IGN_ON_TIGGER=8                                 # Report trigger for ignition on
#--------------------------------------------------------------------------------------------------


#--------------------------------------------------------------------------------------------------
# Copy files and setup report scripts
#--------------------------------------------------------------------------------------------------
MYPATH="/tmp/spreader"
dos2unix $MYPATH/spreader.py
dos2unix $MYPATH/spreader_data.txt
dos2unix $MYPATH/spreader_data.crc

cp $MYPATH/spreader.py /var/data/reports/scripts/
cp $MYPATH/spreader_data.txt /tmp/
cp $MYPATH/spreader_data.crc /tmp/
cp $MYPATH/spreader_data.txt /var/data/reports/scripts/
cp $MYPATH/spreader_data.crc /var/data/reports/scripts/


cp $MYPATH/report$SPREADER_TMP_TO_NV_REPORT.sh /var/data/reports/scripts/
cp $MYPATH/report$SPREADER_NV_TO_TMP_REPORT.sh /var/data/reports/scripts/
cp $MYPATH/report$SPREADER_GPS_REPORT_SCRIPT.sh /var/data/reports/scripts/
cp $MYPATH/report$SPREADER_RESET_REPORT.sh /var/data/reports/scripts/
cp $MYPATH/uninstall_cs550.sh /var/data/reports/scripts/


chmod u+x /var/data/reports/scripts/report$SPREADER_TMP_TO_NV_REPORT.sh
chmod u+x /var/data/reports/scripts/report$SPREADER_NV_TO_TMP_REPORT.sh
chmod u+x /var/data/reports/scripts/report$SPREADER_GPS_REPORT_SCRIPT.sh
chmod u+x /var/data/reports/scripts/report$SPREADER_RESET_REPORT.sh
chmod u+x /var/data/reports/scripts/uninstall_cs550.sh

dos2unix /var/data/reports/scripts/report$SPREADER_TMP_TO_NV_REPORT.sh
dos2unix /var/data/reports/scripts/report$SPREADER_NV_TO_TMP_REPORT.sh
dos2unix /var/data/reports/scripts/report$SPREADER_GPS_REPORT_SCRIPT.sh
dos2unix /var/data/reports/scripts/report$SPREADER_RESET_REPORT.sh
dos2unix /var/data/reports/scripts/uninstall_cs550.sh


#if spreader data doesn't exist yet create it by calling report99.sh
if [ ! -e "/var/data/reports/scripts/spreader_data.txt" ]; then
	touch /tmp/SeasonalReset
	/var/data/reports/scripts/report$SPREADER_RESET_REPORT.sh
fi

#--------------------------------------------------------------------------------------------------
#Configure CTM-200
#--------------------------------------------------------------------------------------------------

# Sets up the ignition on/off triggering
cmd vcccond $VCC_REPORT_TRIGGER 2 8 $DATA_SAVE_TIME
cmd vccreport $VCC_REPORT_TRIGGER $SPREADER_TMP_TO_NV_REPORT

cmd igncond $IGN_OFF_TIGGER 1                                            # Off
cmd ignreport $IGN_OFF_TIGGER $SPREADER_TMP_TO_NV_REPORT

cmd igncond $IGN_ON_TIGGER 2                                            # on
cmd ignreport $IGN_ON_TIGGER $SPREADER_NV_TO_TMP_REPORT

cmd reptype $SPREADER_TMP_TO_NV_REPORT 0 3 0 0 500      # Report type setup
cmd reptype $SPREADER_NV_TO_TMP_REPORT 0 3 0 0 500      # Report type setup

# Setup the serial port and AUX details
cmd port 1 $SPREADER_BAUD_RATE 8 n 1 0
cmd mode 23

cmd aux mode 0
cmd aux datatype 1
cmd aux leadlen 2
cmd aux lead2len 0
cmd aux leadmode 1
cmd aux leadterm 2
cmd aux len 128
cmd aux dev 550
cmd aux polltim 2 400 0
cmd aux term 0D 0A
cmd reportscripts 1
cmd aux cond 1 0 0 0
cmd aux pollstr @1

cmd reportscripts 1

# Setups the the reporting and PCYP data
cmd gpsaddmes $SPREADER_GPS_REPORT 1000

cmd pcyp msg add 1000 USR_STR_1
cmd pcyp msg add 1000 USR_STR_2
cmd pcyp msg add 1000 USR_STR_3
cmd pcyp msg add 1000 USR_STR_4
cmd pcyp msg add 1000 USR_FLT_9

cmd repdelmes $SPREADER_RESET_REPORT 0
cmd repaddmes $SPREADER_RESET_REPORT 114 $SPREADER_RESET_PCYP_STRING
cmd repremip $SPREADER_RESET_REPORT $SPREADER_RESET_DEST
cmd repremport $SPREADER_RESET_REPORT 8300
cmd reptype $SPREADER_RESET_REPORT 0 3 1 0 3000
cmd pcyp msg add $SPREADER_RESET_PCYP_STRING USR_STR_3


cmd save
cmd event add CS550_INSTALL_OK
